# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: onos/provisioner/aspects.proto, onos/provisioner/config.proto
# plugin: python-betterproto
from dataclasses import dataclass
from datetime import datetime
from typing import AsyncIterator, Dict, List, Optional

import betterproto
import grpclib


@dataclass(eq=False, repr=False)
class DeviceConfig(betterproto.Message):
    """
    DeviceConfig is a topology entity aspect used to specify what pipeline and
    chassis config a device should have applied to it
    """

    pipeline_config_id: str = betterproto.string_field(1)
    chassis_config_id: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class PipelineConfigState(betterproto.Message):
    """
    PipelineConfigState is a topology entity aspect used to indicate what
    pipeline config a device has presently applied to it
    """

    config_id: str = betterproto.string_field(1)
    cookie: int = betterproto.uint64_field(2)
    updated: datetime = betterproto.message_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ChassisConfigState(betterproto.Message):
    """
    ChassisConfigState is a topology entity aspect used to indicate what
    chassis config a device has presently applied to it
    """

    config_id: str = betterproto.string_field(1)
    updated: datetime = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ConfigRecord(betterproto.Message):
    """
    DeviceConfig is a topology entity aspect used to specify what pipeline and
    chassis config a device should have applied to it
    """

    config_id: str = betterproto.string_field(1)
    kind: str = betterproto.string_field(3)
    artifacts: List[str] = betterproto.string_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Config(betterproto.Message):
    """
    PipelineConfigState is a topology entity aspect used to indicate what
    pipeline config a device has presently applied to it
    """

    record: "ConfigRecord" = betterproto.message_field(1)
    artifacts: Dict[str, bytes] = betterproto.map_field(
        4, betterproto.TYPE_STRING, betterproto.TYPE_BYTES
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class AddConfigRequest(betterproto.Message):
    """
    ChassisConfigState is a topology entity aspect used to indicate what
    chassis config a device has presently applied to it
    """

    config: "Config" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class AddConfigResponse(betterproto.Message):
    pass

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class DeleteConfigRequest(betterproto.Message):
    config_id: str = betterproto.string_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class DeleteConfigResponse(betterproto.Message):
    pass

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetConfigRequest(betterproto.Message):
    config_id: str = betterproto.string_field(1)
    include_artifacts: bool = betterproto.bool_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetConfigResponse(betterproto.Message):
    config: "Config" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ListConfigsRequest(betterproto.Message):
    kind: str = betterproto.string_field(1)
    include_artifacts: bool = betterproto.bool_field(2)
    watch: bool = betterproto.bool_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ListConfigsResponse(betterproto.Message):
    config: "Config" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


class ProvisionerServiceStub(betterproto.ServiceStub):
    async def add(self, *, config: "Config" = None) -> "AddConfigResponse":

        request = AddConfigRequest()
        if config is not None:
            request.config = config

        return await self._unary_unary(
            "/onos.provisioner.ProvisionerService/Add", request, AddConfigResponse
        )

    async def delete(self, *, config_id: str = "") -> "DeleteConfigResponse":

        request = DeleteConfigRequest()
        request.config_id = config_id

        return await self._unary_unary(
            "/onos.provisioner.ProvisionerService/Delete", request, DeleteConfigResponse
        )

    async def get(
        self, *, config_id: str = "", include_artifacts: bool = False
    ) -> "GetConfigResponse":

        request = GetConfigRequest()
        request.config_id = config_id
        request.include_artifacts = include_artifacts

        return await self._unary_unary(
            "/onos.provisioner.ProvisionerService/Get", request, GetConfigResponse
        )

    async def list(
        self, *, kind: str = "", include_artifacts: bool = False, watch: bool = False
    ) -> AsyncIterator["ListConfigsResponse"]:

        request = ListConfigsRequest()
        request.kind = kind
        request.include_artifacts = include_artifacts
        request.watch = watch

        async for response in self._unary_stream(
            "/onos.provisioner.ProvisionerService/List",
            request,
            ListConfigsResponse,
        ):
            yield response



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: onos/stratum/p4_role_config.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import List

import betterproto


@dataclass(eq=False, repr=False)
class P4RoleConfig(betterproto.Message):
    """
    The P4RoleConfig message conists of these fields:  exclusive_p4_ids - A
    list of P4 entities for which this role exclusivly may      issue Write
    updates. Those entities are also filtered out of Read      responses.
    shared_p4_ids - A list of P4 entities for which this role may issue Write
    updates. Access to those entities is shared with other roles. Those
    entities are also filtered out of Read responses.  packet_in_filter - A
    single PacketFilter that is applied to incoming packets      to determine
    whether this role should receive them. An empty list      results in no
    filtering. This is a positive filter, a packet must      contain the exact
    specified value to be forwarded.  receives_packet_ins - A toggle to set if
    this role should receive PacketIns.  can_push_pipeline - Determines if this
    role is allowed to push a pipeline.
    """

    exclusive_p4_ids: List[int] = betterproto.uint32_field(1)
    shared_p4_ids: List[int] = betterproto.uint32_field(2)
    packet_in_filter: "P4RoleConfigPacketFilter" = betterproto.message_field(3)
    receives_packet_ins: bool = betterproto.bool_field(4)
    can_push_pipeline: bool = betterproto.bool_field(5)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class P4RoleConfigPacketFilter(betterproto.Message):
    metadata_id: int = betterproto.uint32_field(1)
    value: bytes = betterproto.bytes_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: onos/a1t/a1/a1.proto, onos/a1t/a1/ei.proto, onos/a1t/a1/policy.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import AsyncIterable, AsyncIterator, Iterable, Optional, Union

import betterproto
import grpclib


class Encoding(betterproto.Enum):
    PROTO = 0
    JSON = 1


class PayloadType(betterproto.Enum):
    POLICY = 0
    STATUS = 1


@dataclass(eq=False, repr=False)
class Header(betterproto.Message):
    request_id: str = betterproto.string_field(1)
    app_id: str = betterproto.string_field(2)
    app_instance_id: str = betterproto.string_field(3)
    a1_node_id: str = betterproto.string_field(4)
    encoding: "Encoding" = betterproto.enum_field(5)
    payload_type: "PayloadType" = betterproto.enum_field(6)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Result(betterproto.Message):
    success: bool = betterproto.bool_field(1)
    reason: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RequestMessage(betterproto.Message):
    header: "Header" = betterproto.message_field(1)
    payload: bytes = betterproto.bytes_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ResultMessage(betterproto.Message):
    header: "Header" = betterproto.message_field(1)
    payload: bytes = betterproto.bytes_field(2)
    result: "Result" = betterproto.message_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class StatusMessage(betterproto.Message):
    header: "Header" = betterproto.message_field(1)
    payload: bytes = betterproto.bytes_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class AckMessage(betterproto.Message):
    header: "Header" = betterproto.message_field(1)
    payload: bytes = betterproto.bytes_field(2)
    result: "Result" = betterproto.message_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class EiRequestMessage(betterproto.Message):
    ei_job_id: str = betterproto.string_field(1)
    message: "RequestMessage" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class EiResultMessage(betterproto.Message):
    ei_job_id: str = betterproto.string_field(1)
    message: "ResultMessage" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class EiStatusMessage(betterproto.Message):
    ei_job_id: str = betterproto.string_field(1)
    message: "StatusMessage" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class EiAckMessage(betterproto.Message):
    ei_job_id: str = betterproto.string_field(1)
    message: "AckMessage" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class PolicyType(betterproto.Message):
    id: str = betterproto.string_field(1)
    name: str = betterproto.string_field(2)
    version: str = betterproto.string_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class PolicyRequestMessage(betterproto.Message):
    policy_id: str = betterproto.string_field(1)
    policy_type: "PolicyType" = betterproto.message_field(2)
    message: "RequestMessage" = betterproto.message_field(3)
    notification_destination: str = betterproto.string_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class PolicyResultMessage(betterproto.Message):
    policy_id: str = betterproto.string_field(1)
    policy_type: "PolicyType" = betterproto.message_field(2)
    message: "ResultMessage" = betterproto.message_field(3)
    notification_destination: str = betterproto.string_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class PolicyStatusMessage(betterproto.Message):
    policy_id: str = betterproto.string_field(1)
    policy_type: "PolicyType" = betterproto.message_field(2)
    message: "StatusMessage" = betterproto.message_field(3)
    notification_destination: str = betterproto.string_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class PolicyAckMessage(betterproto.Message):
    policy_id: str = betterproto.string_field(1)
    policy_type: "PolicyType" = betterproto.message_field(2)
    message: "AckMessage" = betterproto.message_field(3)
    notification_destination: str = betterproto.string_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


class EiServiceStub(betterproto.ServiceStub):
    async def ei_query(
        self,
        request_iterator: Union[
            AsyncIterable["EiResultMessage"], Iterable["EiResultMessage"]
        ],
    ) -> AsyncIterator["EiRequestMessage"]:

        async for response in self._stream_stream(
            "/onos.a1t.a1.EIService/EIQuery",
            request_iterator,
            EiResultMessage,
            EiRequestMessage,
        ):
            yield response

    async def ei_job_setup(
        self,
        request_iterator: Union[
            AsyncIterable["EiResultMessage"], Iterable["EiResultMessage"]
        ],
    ) -> AsyncIterator["EiRequestMessage"]:

        async for response in self._stream_stream(
            "/onos.a1t.a1.EIService/EIJobSetup",
            request_iterator,
            EiResultMessage,
            EiRequestMessage,
        ):
            yield response

    async def ei_job_update(
        self,
        request_iterator: Union[
            AsyncIterable["EiResultMessage"], Iterable["EiResultMessage"]
        ],
    ) -> AsyncIterator["EiRequestMessage"]:

        async for response in self._stream_stream(
            "/onos.a1t.a1.EIService/EIJobUpdate",
            request_iterator,
            EiResultMessage,
            EiRequestMessage,
        ):
            yield response

    async def ei_job_delete(
        self,
        request_iterator: Union[
            AsyncIterable["EiResultMessage"], Iterable["EiResultMessage"]
        ],
    ) -> AsyncIterator["EiRequestMessage"]:

        async for response in self._stream_stream(
            "/onos.a1t.a1.EIService/EIJobDelete",
            request_iterator,
            EiResultMessage,
            EiRequestMessage,
        ):
            yield response

    async def ei_job_status_query(
        self,
        request_iterator: Union[
            AsyncIterable["EiResultMessage"], Iterable["EiResultMessage"]
        ],
    ) -> AsyncIterator["EiRequestMessage"]:

        async for response in self._stream_stream(
            "/onos.a1t.a1.EIService/EIJobStatusQuery",
            request_iterator,
            EiResultMessage,
            EiRequestMessage,
        ):
            yield response

    async def ei_job_status_notify(self) -> "EiAckMessage":

        request = EiStatusMessage()

        return await self._unary_unary(
            "/onos.a1t.a1.EIService/EIJobStatusNotify", request, EiAckMessage
        )

    async def ei_job_result_delivery(self) -> "EiAckMessage":

        request = EiResultMessage()

        return await self._unary_unary(
            "/onos.a1t.a1.EIService/EIJobResultDelivery", request, EiAckMessage
        )


class PolicyServiceStub(betterproto.ServiceStub):
    async def policy_setup(
        self,
        *,
        policy_id: str = "",
        policy_type: "PolicyType" = None,
        message: "RequestMessage" = None,
        notification_destination: str = "",
    ) -> "PolicyResultMessage":

        request = PolicyRequestMessage()
        request.policy_id = policy_id
        if policy_type is not None:
            request.policy_type = policy_type
        if message is not None:
            request.message = message
        request.notification_destination = notification_destination

        return await self._unary_unary(
            "/onos.a1t.a1.PolicyService/PolicySetup", request, PolicyResultMessage
        )

    async def policy_update(
        self,
        *,
        policy_id: str = "",
        policy_type: "PolicyType" = None,
        message: "RequestMessage" = None,
        notification_destination: str = "",
    ) -> "PolicyResultMessage":

        request = PolicyRequestMessage()
        request.policy_id = policy_id
        if policy_type is not None:
            request.policy_type = policy_type
        if message is not None:
            request.message = message
        request.notification_destination = notification_destination

        return await self._unary_unary(
            "/onos.a1t.a1.PolicyService/PolicyUpdate", request, PolicyResultMessage
        )

    async def policy_delete(
        self,
        *,
        policy_id: str = "",
        policy_type: "PolicyType" = None,
        message: "RequestMessage" = None,
        notification_destination: str = "",
    ) -> "PolicyResultMessage":

        request = PolicyRequestMessage()
        request.policy_id = policy_id
        if policy_type is not None:
            request.policy_type = policy_type
        if message is not None:
            request.message = message
        request.notification_destination = notification_destination

        return await self._unary_unary(
            "/onos.a1t.a1.PolicyService/PolicyDelete", request, PolicyResultMessage
        )

    async def policy_query(
        self,
        *,
        policy_id: str = "",
        policy_type: "PolicyType" = None,
        message: "RequestMessage" = None,
        notification_destination: str = "",
    ) -> "PolicyResultMessage":

        request = PolicyRequestMessage()
        request.policy_id = policy_id
        if policy_type is not None:
            request.policy_type = policy_type
        if message is not None:
            request.message = message
        request.notification_destination = notification_destination

        return await self._unary_unary(
            "/onos.a1t.a1.PolicyService/PolicyQuery", request, PolicyResultMessage
        )

    async def policy_status(
        self,
        request_iterator: Union[
            AsyncIterable["PolicyAckMessage"], Iterable["PolicyAckMessage"]
        ],
    ) -> AsyncIterator["PolicyStatusMessage"]:

        async for response in self._stream_stream(
            "/onos.a1t.a1.PolicyService/PolicyStatus",
            request_iterator,
            PolicyAckMessage,
            PolicyStatusMessage,
        ):
            yield response



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: onos/topo/config.proto, onos/topo/fabric.proto, onos/topo/ran.proto, onos/topo/topo.proto
# plugin: python-betterproto
import warnings
from dataclasses import dataclass
from datetime import datetime, timedelta
from typing import AsyncIterator, Dict, List, Optional

import betterproto
import grpclib


class Protocol(betterproto.Enum):
    """Protocol to interact with a device"""

    # UNKNOWN_PROTOCOL constant needed to go around proto3 nullifying the 0
    # values
    UNKNOWN_PROTOCOL = 0
    # GNMI protocol reference
    GNMI = 1
    # P4RUNTIME protocol reference
    P4RUNTIME = 2
    # GNOI protocol reference
    GNOI = 3
    # E2 Control Plane Protocol
    E2AP = 4


class ConnectivityState(betterproto.Enum):
    """
    ConnectivityState represents the L3 reachability of a device from the
    service container (e.g. enos-config), independently of gRPC or the service
    itself (e.g. gNMI)
    """

    # UNKNOWN_CONNECTIVITY_STATE constant needed to go around proto3 nullifying
    # the 0 values
    UNKNOWN_CONNECTIVITY_STATE = 0
    # REACHABLE indicates the the service can reach the device at L3
    REACHABLE = 1
    # UNREACHABLE indicates the the service can't reach the device at L3
    UNREACHABLE = 2


class ChannelState(betterproto.Enum):
    """
    ConnectivityState represents the state of a gRPC channel to the device from
    the service container
    """

    # UNKNOWN_CHANNEL_STATE constant needed to go around proto3 nullifying the 0
    # values
    UNKNOWN_CHANNEL_STATE = 0
    # CONNECTED indicates the corresponding grpc channel is connected on this
    # device
    CONNECTED = 1
    # DISCONNECTED indicates the corresponding grpc channel is not connected on
    # this device
    DISCONNECTED = 2


class ServiceState(betterproto.Enum):
    """
    ServiceState represents the state of the gRPC service (e.g. gNMI) to the
    device from the service container
    """

    # UNKNOWN_SERVICE_STATE constant needed to go around proto3 nullifying the 0
    # values
    UNKNOWN_SERVICE_STATE = 0
    # AVAILABLE indicates the corresponding grpc service is available
    AVAILABLE = 1
    # UNAVAILABLE indicates the corresponding grpc service is not available
    UNAVAILABLE = 2
    # CONNECTING indicates the corresponding protocol is in the connecting phase
    # on this device
    CONNECTING = 3


class IpAddressType(betterproto.Enum):
    IPV4 = 0
    IPV6 = 1


class NetworkLayerType(betterproto.Enum):
    UNDERLAY = 0


class ControllerInfoType(betterproto.Enum):
    P4RUNTIME = 0


class P4PipelineInfoConfigurationAction(betterproto.Enum):
    UNSPECIFIED = 0
    VERIFY = 1
    VERIFY_AND_SAVE = 2
    VERIFY_AND_COMMIT = 3
    COMMIT = 4
    RECONCILE_AND_COMMIT = 5


class RanEntityKinds(betterproto.Enum):
    """Protocol to interact with a device"""

    # UNKNOWN_PROTOCOL constant needed to go around proto3 nullifying the 0
    # values
    E2NODE = 0
    # GNMI protocol reference
    E2CELL = 1
    # P4RUNTIME protocol reference
    E2T = 3
    # GNOI protocol reference
    XAPP = 4
    # E2 Control Plane Protocol
    A1T = 5


class RanRelationKinds(betterproto.Enum):
    """
    ConnectivityState represents the L3 reachability of a device from the
    service container (e.g. enos-config), independently of gRPC or the service
    itself (e.g. gNMI)
    """

    # UNKNOWN_CONNECTIVITY_STATE constant needed to go around proto3 nullifying
    # the 0 values
    CONTROLS = 0
    # REACHABLE indicates the the service can reach the device at L3
    CONTAINS = 1
    # UNREACHABLE indicates the the service can't reach the device at L3
    NEIGHBORS = 2


class CellGlobalIdType(betterproto.Enum):
    """
    ConnectivityState represents the state of a gRPC channel to the device from
    the service container
    """

    # UNKNOWN_CHANNEL_STATE constant needed to go around proto3 nullifying the 0
    # values
    NRCGI = 0
    # CONNECTED indicates the corresponding grpc channel is connected on this
    # device
    ECGI = 1


class NodeType(betterproto.Enum):
    """
    ServiceState represents the state of the gRPC service (e.g. gNMI) to the
    device from the service container
    """

    # UNKNOWN_SERVICE_STATE constant needed to go around proto3 nullifying the 0
    # values
    NT_NONE = 0
    # AVAILABLE indicates the corresponding grpc service is available
    NT_GNB = 1
    # UNAVAILABLE indicates the corresponding grpc service is not available
    NT_EN_GNB = 2
    # CONNECTING indicates the corresponding protocol is in the connecting phase
    # on this device
    NT_NG_ENB = 3
    NT_ENB = 4


class ComponentType(betterproto.Enum):
    CT_NONE = 0
    CT_CU = 1
    CT_CU_UP = 2
    CT_DU = 3
    CT_ENB = 4


class E2SmRsmCommand(betterproto.Enum):
    E2_SM_RSM_COMMAND_SLICE_CREATE = 0
    E2_SM_RSM_COMMAND_SLICE_UPDATE = 1
    E2_SM_RSM_COMMAND_SLICE_DELETE = 2
    E2_SM_RSM_COMMAND_UE_ASSOCIATE = 3
    E2_SM_RSM_COMMAND_EVENT_TRIGGERS = 4


class RsmSlicingType(betterproto.Enum):
    SLICING_TYPE_STATIC = 0
    SLICING_TYPE_DYNAMIC = 1


class RsmSchedulerType(betterproto.Enum):
    SCHEDULER_TYPE_ROUND_ROBIN = 0
    SCHEDULER_TYPE_PROPORTIONALLY_FAIR = 1
    SCHEDULER_TYPE_QOS_BASED = 2


class RsmSliceType(betterproto.Enum):
    SLICE_TYPE_DL_SLICE = 0
    SLICE_TYPE_UL_SLICE = 1


class UeIdType(betterproto.Enum):
    UE_ID_TYPE_CU_UE_F1_AP_ID = 0
    UE_ID_TYPE_DU_UE_F1_AP_ID = 1
    UE_ID_TYPE_RAN_UE_NGAP_ID = 2
    UE_ID_TYPE_AMF_UE_NGAP_ID = 3
    UE_ID_TYPE_ENB_UE_S1_AP_ID = 4


class NrScs(betterproto.Enum):
    SCS_UNKNOWN = 0
    SCS_15 = 1
    SCS_30 = 2
    SCS_50 = 3
    SCS_120 = 4


class Nrb(betterproto.Enum):
    NRB_UNKNOWN = 0
    NRB_11 = 1
    NRB_18 = 2
    NRB_24 = 3
    NRB_25 = 4
    NRB_31 = 5
    NRB_32 = 6
    NRB_38 = 7
    NRB_51 = 8
    NRB_52 = 9
    NRB_65 = 10
    NRB_66 = 11
    NRB_78 = 12
    NRB_79 = 13
    NRB_93 = 14
    NRB_106 = 15
    NRB_107 = 16
    NRB_121 = 17
    NRB_132 = 18
    NRB_133 = 19
    NRB_135 = 20
    NRB_160 = 21
    NRB_162 = 22
    NRB_189 = 23
    NRB_216 = 24
    NRB_217 = 25
    NRB_245 = 26
    NRB_264 = 27
    NRB_270 = 28
    NRB_273 = 29


class EnDcSupport(betterproto.Enum):
    EN_DC_SUPPORT_UNKNOWN = 0
    EN_DC_SUPPORT_SUPPORTED = 1
    EN_DC_SUPPORT_NOT_SUPPORTED = 2


class InterfaceType(betterproto.Enum):
    INTERFACE_UNKNOWN = 0
    INTERFACE_E2T = 1
    INTERFACE_E2AP101 = 2
    INTERFACE_E2AP200 = 3
    INTERFACE_A1_XAPP = 4
    INTERFACE_A1AP = 5


class EventType(betterproto.Enum):
    """Protocol to interact with a device"""

    # UNKNOWN_PROTOCOL constant needed to go around proto3 nullifying the 0
    # values
    NONE = 0
    # GNMI protocol reference
    ADDED = 1
    # P4RUNTIME protocol reference
    UPDATED = 2
    # GNOI protocol reference
    REMOVED = 3


class RelationFilterScope(betterproto.Enum):
    """
    ConnectivityState represents the L3 reachability of a device from the
    service container (e.g. enos-config), independently of gRPC or the service
    itself (e.g. gNMI)
    """

    # UNKNOWN_CONNECTIVITY_STATE constant needed to go around proto3 nullifying
    # the 0 values
    TARGETS_ONLY = 0
    # REACHABLE indicates the the service can reach the device at L3
    ALL = 1
    # UNREACHABLE indicates the the service can't reach the device at L3
    SOURCE_AND_TARGETS = 2
    RELATIONS_ONLY = 3
    RELATIONS_AND_TARGETS = 4


class SortOrder(betterproto.Enum):
    """
    ConnectivityState represents the state of a gRPC channel to the device from
    the service container
    """

    # UNKNOWN_CHANNEL_STATE constant needed to go around proto3 nullifying the 0
    # values
    UNORDERED = 0
    # CONNECTED indicates the corresponding grpc channel is connected on this
    # device
    ASCENDING = 1
    # DISCONNECTED indicates the corresponding grpc channel is not connected on
    # this device
    DESCENDING = 2


class ObjectType(betterproto.Enum):
    UNSPECIFIED = 0
    ENTITY = 1
    RELATION = 2
    KIND = 3


@dataclass(eq=False, repr=False)
class Asset(betterproto.Message):
    """Basic asset information"""

    name: str = betterproto.string_field(1)
    manufacturer: str = betterproto.string_field(2)
    model: str = betterproto.string_field(3)
    serial: str = betterproto.string_field(4)
    asset: str = betterproto.string_field(5)
    sw_version: str = betterproto.string_field(6)
    role: str = betterproto.string_field(8)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Configurable(betterproto.Message):
    """Configurable device aspect"""

    type: str = betterproto.string_field(1)
    address: str = betterproto.string_field(2)
    target: str = betterproto.string_field(3)
    version: str = betterproto.string_field(4)
    timeout: timedelta = betterproto.message_field(5)
    persistent: bool = betterproto.bool_field(6)
    validate_capabilities: bool = betterproto.bool_field(7)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class MastershipState(betterproto.Message):
    """Aspect for tracking device mastership"""

    term: int = betterproto.uint64_field(1)
    node_id: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TlsOptions(betterproto.Message):
    """TLS connectivity aspect"""

    insecure: bool = betterproto.bool_field(1)
    plain: bool = betterproto.bool_field(2)
    key: str = betterproto.string_field(3)
    ca_cert: str = betterproto.string_field(4)
    cert: str = betterproto.string_field(5)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class AdHoc(betterproto.Message):
    """Aspect for ad-hoc properties"""

    properties: Dict[str, str] = betterproto.map_field(
        1, betterproto.TYPE_STRING, betterproto.TYPE_STRING
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ProtocolState(betterproto.Message):
    """
    ProtocolState contains information related to service and connectivity to a
    device
    """

    # The protocol to which state relates
    protocol: "Protocol" = betterproto.enum_field(1)
    # ConnectivityState contains the L3 connectivity information
    connectivity_state: "ConnectivityState" = betterproto.enum_field(2)
    # ChannelState relates to the availability of the gRPC channel
    channel_state: "ChannelState" = betterproto.enum_field(3)
    # ServiceState indicates the availability of the gRPC servic on top of the
    # channel
    service_state: "ServiceState" = betterproto.enum_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Protocols(betterproto.Message):
    """Protocols"""

    state: List["ProtocolState"] = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Endpoint(betterproto.Message):
    """Basic asset information"""

    address: str = betterproto.string_field(1)
    port: int = betterproto.uint32_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class IpAddress(betterproto.Message):
    """Configurable device aspect"""

    type: "IpAddressType" = betterproto.enum_field(1)
    ip: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class P4RuntimeServer(betterproto.Message):
    """Aspect for tracking device mastership"""

    endpoint: "Endpoint" = betterproto.message_field(1)
    device_id: int = betterproto.uint64_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GNmiServer(betterproto.Message):
    """TLS connectivity aspect"""

    endpoint: "Endpoint" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class NetworkLayer(betterproto.Message):
    """Aspect for ad-hoc properties"""

    type: "NetworkLayerType" = betterproto.enum_field(1)
    display_name: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Switch(betterproto.Message):
    """
    ProtocolState contains information related to service and connectivity to a
    device
    """

    # The protocol to which state relates
    model_id: str = betterproto.string_field(1)
    # ConnectivityState contains the L3 connectivity information
    role: str = betterproto.string_field(2)
    # ChannelState relates to the availability of the gRPC channel
    management_endpoint: "Endpoint" = betterproto.message_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Router(betterproto.Message):
    """Protocols"""

    model_id: str = betterproto.string_field(1)
    role: str = betterproto.string_field(2)
    management_endpoint: "Endpoint" = betterproto.message_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Link(betterproto.Message):
    source_ip: "IpAddress" = betterproto.message_field(1)
    dest_ip: "IpAddress" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Port(betterproto.Message):
    index: int = betterproto.uint32_field(1)
    number: int = betterproto.uint32_field(2)
    display_name: str = betterproto.string_field(3)
    enabled: bool = betterproto.bool_field(4)
    speed: str = betterproto.string_field(5)
    status: str = betterproto.string_field(6)
    last_change: int = betterproto.uint64_field(7)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class PhyInterface(betterproto.Message):
    display_name: str = betterproto.string_field(1)
    speed: str = betterproto.string_field(2)
    port_number: int = betterproto.uint32_field(3)
    channel_number: int = betterproto.uint32_field(4)
    target_id: str = betterproto.string_field(5)
    enabled: bool = betterproto.bool_field(6)
    health_indicator: str = betterproto.string_field(7)
    if_index: int = betterproto.uint32_field(8)
    mac_address: str = betterproto.string_field(9)
    auto_negotiate: bool = betterproto.bool_field(10)
    ip: "IpAddress" = betterproto.message_field(11)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ControllerInfo(betterproto.Message):
    type: "ControllerInfoType" = betterproto.enum_field(1)
    role: "ControllerRole" = betterproto.message_field(2)
    control_endpoint: "Endpoint" = betterproto.message_field(3)
    username: str = betterproto.string_field(4)
    password: str = betterproto.string_field(5)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ControllerRole(betterproto.Message):
    name: str = betterproto.string_field(1)
    config: "betterproto_lib_google_protobuf.Any" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class P4RtServerInfo(betterproto.Message):
    control_endpoint: "Endpoint" = betterproto.message_field(1)
    timeout: timedelta = betterproto.message_field(2)
    device_id: int = betterproto.uint64_field(3)
    pipelines: List["P4PipelineInfo"] = betterproto.message_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class P4PipelineInfo(betterproto.Message):
    name: str = betterproto.string_field(1)
    version: str = betterproto.string_field(2)
    architecture: str = betterproto.string_field(3)
    configuration_action: "P4PipelineInfoConfigurationAction" = betterproto.enum_field(
        4
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class P4RtMastershipState(betterproto.Message):
    term: int = betterproto.uint64_field(1)
    connection_id: str = betterproto.string_field(2)
    role: str = betterproto.string_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Service(betterproto.Message):
    target_id: str = betterproto.string_field(1)
    mastershipstate: "P4RtMastershipState" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Location(betterproto.Message):
    """Basic asset information"""

    lat: float = betterproto.double_field(1)
    lng: float = betterproto.double_field(2)
    wgs84: "Wgs84Location" = betterproto.message_field(3, group="ext")
    cartesian: "CartesianLocation" = betterproto.message_field(4, group="ext")

    def __post_init__(self) -> None:
        super().__post_init__()
        if self.lat:
            warnings.warn("Location.lat is deprecated", DeprecationWarning)
        if self.lng:
            warnings.warn("Location.lng is deprecated", DeprecationWarning)


@dataclass(eq=False, repr=False)
class Wgs84Location(betterproto.Message):
    """Configurable device aspect"""

    latitude_deg: float = betterproto.double_field(1)
    longitude_deg: float = betterproto.double_field(2)
    altitude_m: float = betterproto.double_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class CartesianLocation(betterproto.Message):
    """Aspect for tracking device mastership"""

    x_m: float = betterproto.double_field(1)
    y_m: float = betterproto.double_field(2)
    z_m: float = betterproto.double_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class AzElOrientation(betterproto.Message):
    """TLS connectivity aspect"""

    azimuth_deg: float = betterproto.double_field(1)
    elevation_deg: float = betterproto.double_field(2)
    rotation_deg: float = betterproto.double_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class YprOrientation(betterproto.Message):
    """Aspect for ad-hoc properties"""

    yaw_deg: float = betterproto.double_field(1)
    pitch_deg: float = betterproto.double_field(2)
    roll_deg: float = betterproto.double_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Orientation(betterproto.Message):
    """
    ProtocolState contains information related to service and connectivity to a
    device
    """

    # The protocol to which state relates
    azel: "AzElOrientation" = betterproto.message_field(1, group="orientation")
    # ConnectivityState contains the L3 connectivity information
    ypr: "YprOrientation" = betterproto.message_field(2, group="orientation")

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Waypoint(betterproto.Message):
    """Protocols"""

    time: datetime = betterproto.message_field(1)
    location: "Location" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Waypoints(betterproto.Message):
    waypoint: List["Waypoint"] = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class OrbitData(betterproto.Message):
    epoch: datetime = betterproto.message_field(1)
    inclination_deg: float = betterproto.double_field(2)
    raan_deg: float = betterproto.double_field(3)
    e: float = betterproto.double_field(4)
    argument_deg: float = betterproto.double_field(5)
    anomaly_deg: float = betterproto.double_field(6)
    mean_motion: float = betterproto.double_field(7)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Motion(betterproto.Message):
    fixed_location: "Location" = betterproto.message_field(1, group="motion")
    waypoints: "Waypoints" = betterproto.message_field(2, group="motion")
    orbit: "OrbitData" = betterproto.message_field(3, group="motion")

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Coverage(betterproto.Message):
    height: int = betterproto.int32_field(1)
    arc_width: int = betterproto.int32_field(2)
    azimuth: int = betterproto.int32_field(3)
    tilt: int = betterproto.int32_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class E2Node(betterproto.Message):
    service_models: Dict[str, "ServiceModelInfo"] = betterproto.map_field(
        1, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class E2NodeConfig(betterproto.Message):
    connections: List["Interface"] = betterproto.message_field(1)
    version: int = betterproto.uint64_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Lease(betterproto.Message):
    expiration: datetime = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Interface(betterproto.Message):
    type: "InterfaceType" = betterproto.enum_field(1)
    ip: str = betterproto.string_field(2)
    port: int = betterproto.uint32_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class E2TInfo(betterproto.Message):
    interfaces: List["Interface"] = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class XAppInfo(betterproto.Message):
    interfaces: List["Interface"] = betterproto.message_field(1)
    a1_policy_types: List["A1PolicyType"] = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class A1PolicyType(betterproto.Message):
    id: str = betterproto.string_field(1)
    name: str = betterproto.string_field(2)
    version: str = betterproto.string_field(3)
    description: str = betterproto.string_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class A1TInfo(betterproto.Message):
    interfaces: List["Interface"] = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class CellGlobalId(betterproto.Message):
    value: str = betterproto.string_field(1)
    type: "CellGlobalIdType" = betterproto.enum_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class NeighborCellId(betterproto.Message):
    cell_global_id: "CellGlobalId" = betterproto.message_field(1)
    plmn_id: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class E2Cell(betterproto.Message):
    cell_object_id: str = betterproto.string_field(1)
    cell_global_id: "CellGlobalId" = betterproto.message_field(2)
    antenna_count: int = betterproto.uint32_field(3)
    arfcn: int = betterproto.uint32_field(4)
    cell_type: str = betterproto.string_field(5)
    pci: int = betterproto.uint32_field(6)
    kpi_reports: Dict[str, int] = betterproto.map_field(
        7, betterproto.TYPE_STRING, betterproto.TYPE_UINT32
    )
    neighbor_cell_ids: List["NeighborCellId"] = betterproto.message_field(8)
    gnb_du_id: int = betterproto.uint32_field(9)
    latest_rrc_version: int = betterproto.uint32_field(10)
    plmn_id: int = betterproto.uint32_field(11)
    served_plmns: List[int] = betterproto.uint32_field(12)
    fdd_info: "FddInfo" = betterproto.message_field(13, group="nr_mode_info")
    tdd_info: "TddInfo" = betterproto.message_field(14, group="nr_mode_info")
    measurement_timing_configuration: int = betterproto.uint32_field(15)
    global_ng_ran_node_id: "GlobalNgRanNodeId" = betterproto.message_field(16)
    tai_support_list: "TaiSupportList" = betterproto.message_field(17)
    amf_region_information: "AmfRegionInformation" = betterproto.message_field(18)
    connectivity_support: "ConnectivitySupport" = betterproto.message_field(19)
    neighbor_information_nrs: List["NeighborInformationNr"] = betterproto.message_field(
        20
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ConnectivitySupport(betterproto.Message):
    en_dc_support: "EnDcSupport" = betterproto.enum_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class FddInfo(betterproto.Message):
    ul_freq_info: "FrequencyInfo" = betterproto.message_field(1)
    dl_freq_info: "FrequencyInfo" = betterproto.message_field(2)
    ul_transmission_bandwidth: "TransmissionBandwidth" = betterproto.message_field(3)
    dl_transmission_bandwidth: "TransmissionBandwidth" = betterproto.message_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TddInfo(betterproto.Message):
    nr_freq_info: "FrequencyInfo" = betterproto.message_field(1)
    transmission_bandwidth: "TransmissionBandwidth" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class FrequencyInfo(betterproto.Message):
    nr_arfcn: int = betterproto.uint32_field(1)
    frequency_band_list: "FrequencyBandList" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TransmissionBandwidth(betterproto.Message):
    nr_scs: "NrScs" = betterproto.enum_field(1)
    nrb: "Nrb" = betterproto.enum_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class FrequencyBandList(betterproto.Message):
    frequency_band_items: List["FrequencyBandItem"] = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class FrequencyBandItem(betterproto.Message):
    nr_frequency_band: int = betterproto.uint32_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GlobalNgRanNodeId(betterproto.Message):
    global_gnb_id: "GlobalGnbId" = betterproto.message_field(
        1, group="global_ng_ran_node_id"
    )
    global_ng_enb_id: "GlobalNgEnbId" = betterproto.message_field(
        2, group="global_ng_ran_node_id"
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GlobalGnbId(betterproto.Message):
    plmn_id: int = betterproto.uint32_field(1)
    gnb_id: int = betterproto.uint32_field(2)
    gnb_id_len: int = betterproto.uint32_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GlobalNgEnbId(betterproto.Message):
    plmn_id: int = betterproto.uint32_field(1)
    macro_ng_enb_id: int = betterproto.uint32_field(2, group="ng_enb_id")
    short_macro_ng_enb_id: int = betterproto.uint32_field(3, group="ng_enb_id")
    long_macro_ng_enb_id: int = betterproto.uint32_field(4, group="ng_enb_id")

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TaiSupportList(betterproto.Message):
    tai_support_items: List["TaiSupportItem"] = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TaiSupportItem(betterproto.Message):
    tac: int = betterproto.uint32_field(1)
    broadcast_plmns: List["XnBroadcastPlmn"] = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class XnBroadcastPlmn(betterproto.Message):
    plmn_id: int = betterproto.uint32_field(1)
    tai_slice_support_list: "TaiSliceSupportList" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TaiSliceSupportList(betterproto.Message):
    slice_support_items: List["SliceSupportItem"] = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class SliceSupportItem(betterproto.Message):
    s_nssai: "SNssai" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class SNssai(betterproto.Message):
    sst: int = betterproto.uint32_field(1)
    sd: int = betterproto.uint32_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class AmfRegionInformation(betterproto.Message):
    global_amf_region_information_items: List[
        "GlobalAmfRegionInformationItem"
    ] = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GlobalAmfRegionInformationItem(betterproto.Message):
    plmn_id: int = betterproto.uint32_field(1)
    amf_region_id: int = betterproto.uint32_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class NeighborInformationNr(betterproto.Message):
    pci: int = betterproto.uint32_field(1)
    nr_cgi: "NeighborCellId" = betterproto.message_field(2)
    tac: int = betterproto.uint32_field(3)
    fdd_info: "FddInfo" = betterproto.message_field(4, group="nr_mode_info")
    tdd_info: "TddInfo" = betterproto.message_field(5, group="nr_mode_info")
    connectivity_support: "ConnectivitySupport" = betterproto.message_field(6)
    measurement_timing_configuration: int = betterproto.uint32_field(7)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ServiceModelInfo(betterproto.Message):
    oid: str = betterproto.string_field(1)
    name: str = betterproto.string_field(2)
    ran_functions: List[
        "betterproto_lib_google_protobuf.Any"
    ] = betterproto.message_field(3)
    ran_function_i_ds: List[int] = betterproto.uint32_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RcRanFunction(betterproto.Message):
    id: str = betterproto.string_field(1)
    report_styles: List["RcReportStyle"] = betterproto.message_field(2)
    insert_styles: List["RcInsertStyle"] = betterproto.message_field(3)
    event_trigger_styles: List["RcEventTriggerStyle"] = betterproto.message_field(4)
    policy_styles: List["RcPolicyStyle"] = betterproto.message_field(5)
    control_styles: List["RcControlStyle"] = betterproto.message_field(6)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class MhoRanFunction(betterproto.Message):
    id: str = betterproto.string_field(1)
    report_styles: List["MhoReportStyle"] = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class KpmRanFunction(betterproto.Message):
    id: str = betterproto.string_field(1)
    report_styles: List["KpmReportStyle"] = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RsmRanFunction(betterproto.Message):
    id: str = betterproto.string_field(1)
    ric_slicing_node_capability_list: List[
        "RsmNodeSlicingCapabilityItem"
    ] = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RcEventTriggerStyle(betterproto.Message):
    name: str = betterproto.string_field(1)
    type: int = betterproto.int32_field(2)
    format_type: int = betterproto.int32_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RcReportStyle(betterproto.Message):
    name: str = betterproto.string_field(1)
    type: int = betterproto.int32_field(2)
    ran_parameters: List["RanParameter"] = betterproto.message_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RcInsertStyle(betterproto.Message):
    name: str = betterproto.string_field(1)
    type: int = betterproto.int32_field(2)
    insert_indications: List["InsertIndication"] = betterproto.message_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RcPolicyStyle(betterproto.Message):
    name: str = betterproto.string_field(1)
    type: int = betterproto.int32_field(2)
    policy_actions: List["PolicyAction"] = betterproto.message_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class PolicyAction(betterproto.Message):
    id: int = betterproto.int32_field(1)
    name: str = betterproto.string_field(2)
    policy_action_ran_parameters: List["RanParameter"] = betterproto.message_field(3)
    policy_condition_ran_parameters: List["RanParameter"] = betterproto.message_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RcControlStyle(betterproto.Message):
    name: str = betterproto.string_field(1)
    type: int = betterproto.int32_field(2)
    header_format_type: int = betterproto.int32_field(3)
    message_format_type: int = betterproto.int32_field(4)
    control_outcome_format_type: int = betterproto.int32_field(5)
    control_actions: List["ControlAction"] = betterproto.message_field(6)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ControlAction(betterproto.Message):
    id: int = betterproto.int32_field(1)
    name: str = betterproto.string_field(2)
    ran_parameters: List["RanParameter"] = betterproto.message_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class InsertIndication(betterproto.Message):
    id: int = betterproto.int32_field(1)
    name: str = betterproto.string_field(2)
    ran_parameters: List["RanParameter"] = betterproto.message_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RanParameter(betterproto.Message):
    id: int = betterproto.int64_field(1)
    name: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class KpmReportStyle(betterproto.Message):
    name: str = betterproto.string_field(1)
    type: int = betterproto.int32_field(2)
    measurements: List["KpmMeasurement"] = betterproto.message_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class MhoReportStyle(betterproto.Message):
    name: str = betterproto.string_field(1)
    type: int = betterproto.int32_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class KpmMeasurement(betterproto.Message):
    id: str = betterproto.string_field(1)
    name: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RsmNodeSlicingCapabilityItem(betterproto.Message):
    max_number_of_slices_dl: int = betterproto.int32_field(1)
    max_number_of_slices_ul: int = betterproto.int32_field(2)
    slicing_type: "RsmSlicingType" = betterproto.enum_field(3)
    max_number_of_ues_per_slice: int = betterproto.int32_field(4)
    supported_config: List["RsmSupportedSlicingConfigItem"] = betterproto.message_field(
        5
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RsmSupportedSlicingConfigItem(betterproto.Message):
    slicing_config_type: "E2SmRsmCommand" = betterproto.enum_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RsmSliceItemList(betterproto.Message):
    rsm_slice_list: List["RsmSlicingItem"] = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RsmSlicingItem(betterproto.Message):
    id: str = betterproto.string_field(1)
    slice_desc: str = betterproto.string_field(2)
    slice_parameters: "RsmSliceParameters" = betterproto.message_field(3)
    slice_type: "RsmSliceType" = betterproto.enum_field(4)
    ue_id_list: List["UeIdentity"] = betterproto.message_field(5)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RsmSliceParameters(betterproto.Message):
    scheduler_type: "RsmSchedulerType" = betterproto.enum_field(1)
    weight: int = betterproto.int32_field(2)
    qos_level: int = betterproto.int32_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class DuUeF1ApId(betterproto.Message):
    value: int = betterproto.int64_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class CuUeF1ApId(betterproto.Message):
    value: int = betterproto.int64_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RanUeNgapId(betterproto.Message):
    value: int = betterproto.int64_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class EnbUeS1ApId(betterproto.Message):
    value: int = betterproto.int32_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class AmfUeNgapId(betterproto.Message):
    value: int = betterproto.int64_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class UeIdentity(betterproto.Message):
    du_ue_f1_ap_id: "DuUeF1ApId" = betterproto.message_field(1)
    cu_ue_f1_ap_id: "CuUeF1ApId" = betterproto.message_field(2)
    ran_ue_ngap_id: "RanUeNgapId" = betterproto.message_field(3)
    enb_ue_s1_ap_id: "EnbUeS1ApId" = betterproto.message_field(4)
    amf_ue_ngap_id: "AmfUeNgapId" = betterproto.message_field(5)
    preferred_id_type: "UeIdType" = betterproto.enum_field(6)
    drb_id: "DrbId" = betterproto.message_field(7)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class DrbId(betterproto.Message):
    four_gdrb_id: "FourGDrbId" = betterproto.message_field(1, group="drb_id")
    five_gdrb_id: "FiveGDrbId" = betterproto.message_field(2, group="drb_id")

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class FiveGDrbId(betterproto.Message):
    value: int = betterproto.int32_field(1)
    qfi: "Qfi" = betterproto.message_field(2)
    flows_map_to_drb: List["QoSflowLevelParameters"] = betterproto.message_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Qfi(betterproto.Message):
    value: int = betterproto.int32_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class QoSflowLevelParameters(betterproto.Message):
    dynamic_five_qi: "DynamicFiveQi" = betterproto.message_field(
        1, group="qos_flow_level_parameters"
    )
    non_dynamic_five_qi: "NonDynamicFiveQi" = betterproto.message_field(
        2, group="qos_flow_level_parameters"
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class DynamicFiveQi(betterproto.Message):
    priority_level: int = betterproto.int32_field(1)
    packet_delay_budge: int = betterproto.int32_field(2)
    packet_error_rate: int = betterproto.int32_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class NonDynamicFiveQi(betterproto.Message):
    five_qi: "FiveQi" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class FiveQi(betterproto.Message):
    value: int = betterproto.int32_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class FourGDrbId(betterproto.Message):
    value: int = betterproto.int32_field(1)
    qci: "Qci" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Qci(betterproto.Message):
    value: int = betterproto.int32_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Event(betterproto.Message):
    """Basic asset information"""

    type: "EventType" = betterproto.enum_field(1)
    object: "Object" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class CreateRequest(betterproto.Message):
    """Configurable device aspect"""

    object: "Object" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class CreateResponse(betterproto.Message):
    """Aspect for tracking device mastership"""

    object: "Object" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetRequest(betterproto.Message):
    """TLS connectivity aspect"""

    id: str = betterproto.string_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetResponse(betterproto.Message):
    """Aspect for ad-hoc properties"""

    object: "Object" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class UpdateRequest(betterproto.Message):
    """
    ProtocolState contains information related to service and connectivity to a
    device
    """

    # The protocol to which state relates
    object: "Object" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class UpdateResponse(betterproto.Message):
    """Protocols"""

    object: "Object" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class DeleteRequest(betterproto.Message):
    id: str = betterproto.string_field(1)
    revision: int = betterproto.uint64_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class DeleteResponse(betterproto.Message):
    pass

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Filter(betterproto.Message):
    equal: "EqualFilter" = betterproto.message_field(1, group="filter")
    not_: "NotFilter" = betterproto.message_field(2, group="filter")
    in_: "InFilter" = betterproto.message_field(3, group="filter")
    key: str = betterproto.string_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class EqualFilter(betterproto.Message):
    value: str = betterproto.string_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class InFilter(betterproto.Message):
    values: List[str] = betterproto.string_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class NotFilter(betterproto.Message):
    inner: "Filter" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RelationFilter(betterproto.Message):
    src_id: str = betterproto.string_field(1)
    relation_kind: str = betterproto.string_field(2)
    target_kind: str = betterproto.string_field(3)
    scope: "RelationFilterScope" = betterproto.enum_field(4)
    target_id: str = betterproto.string_field(5)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Filters(betterproto.Message):
    kind_filter: "Filter" = betterproto.message_field(1)
    label_filters: List["Filter"] = betterproto.message_field(2)
    relation_filter: "RelationFilter" = betterproto.message_field(3)
    object_types: List["ObjectType"] = betterproto.enum_field(4)
    with_aspects: List[str] = betterproto.string_field(6)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class QueryRequest(betterproto.Message):
    filters: "Filters" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class QueryResponse(betterproto.Message):
    object: "Object" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ListRequest(betterproto.Message):
    filters: "Filters" = betterproto.message_field(1)
    sort_order: "SortOrder" = betterproto.enum_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ListResponse(betterproto.Message):
    objects: List["Object"] = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class WatchRequest(betterproto.Message):
    filters: "Filters" = betterproto.message_field(1)
    noreplay: bool = betterproto.bool_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class WatchResponse(betterproto.Message):
    event: "Event" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Object(betterproto.Message):
    uuid: str = betterproto.string_field(9)
    id: str = betterproto.string_field(1)
    revision: int = betterproto.uint64_field(2)
    type: "ObjectType" = betterproto.enum_field(3)
    entity: "Entity" = betterproto.message_field(4, group="obj")
    relation: "Relation" = betterproto.message_field(5, group="obj")
    kind: "Kind" = betterproto.message_field(6, group="obj")
    aspects: Dict[str, "betterproto_lib_google_protobuf.Any"] = betterproto.map_field(
        7, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )
    labels: Dict[str, str] = betterproto.map_field(
        8, betterproto.TYPE_STRING, betterproto.TYPE_STRING
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Entity(betterproto.Message):
    kind_id: str = betterproto.string_field(1)
    src_relation_ids: List[str] = betterproto.string_field(2)
    tgt_relation_ids: List[str] = betterproto.string_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Relation(betterproto.Message):
    kind_id: str = betterproto.string_field(1)
    src_entity_id: str = betterproto.string_field(2)
    tgt_entity_id: str = betterproto.string_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Kind(betterproto.Message):
    name: str = betterproto.string_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


class TopoStub(betterproto.ServiceStub):
    async def create(self, *, object: "Object" = None) -> "CreateResponse":

        request = CreateRequest()
        if object is not None:
            request.object = object

        return await self._unary_unary(
            "/onos.topo.Topo/Create", request, CreateResponse
        )

    async def get(self, *, id: str = "") -> "GetResponse":

        request = GetRequest()
        request.id = id

        return await self._unary_unary("/onos.topo.Topo/Get", request, GetResponse)

    async def update(self, *, object: "Object" = None) -> "UpdateResponse":

        request = UpdateRequest()
        if object is not None:
            request.object = object

        return await self._unary_unary(
            "/onos.topo.Topo/Update", request, UpdateResponse
        )

    async def delete(self, *, id: str = "", revision: int = 0) -> "DeleteResponse":

        request = DeleteRequest()
        request.id = id
        request.revision = revision

        return await self._unary_unary(
            "/onos.topo.Topo/Delete", request, DeleteResponse
        )

    async def query(
        self, *, filters: "Filters" = None
    ) -> AsyncIterator["QueryResponse"]:

        request = QueryRequest()
        if filters is not None:
            request.filters = filters

        async for response in self._unary_stream(
            "/onos.topo.Topo/Query",
            request,
            QueryResponse,
        ):
            yield response

    async def list(
        self, *, filters: "Filters" = None, sort_order: "SortOrder" = None
    ) -> "ListResponse":

        request = ListRequest()
        if filters is not None:
            request.filters = filters
        request.sort_order = sort_order

        return await self._unary_unary("/onos.topo.Topo/List", request, ListResponse)

    async def watch(
        self, *, filters: "Filters" = None, noreplay: bool = False
    ) -> AsyncIterator["WatchResponse"]:

        request = WatchRequest()
        if filters is not None:
            request.filters = filters
        request.noreplay = noreplay

        async for response in self._unary_stream(
            "/onos.topo.Topo/Watch",
            request,
            WatchResponse,
        ):
            yield response


import betterproto.lib.google.protobuf as betterproto_lib_google_protobuf



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: onos/misc/misc.proto
# plugin: python-betterproto
from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class GridPosition(betterproto.Message):
    """
    GridPosition indicates where on a grid an entity should be located; used
    for visualization purposes
    """

    x: int = betterproto.int32_field(1)
    y: int = betterproto.int32_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Connection(betterproto.Message):
    """
    Connection contains information about a single gRPC client connection
    """

    from_address: str = betterproto.string_field(1)
    protocol: str = betterproto.string_field(2)
    time: int = betterproto.int64_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class IoStats(betterproto.Message):
    """IOStats represents I/O statistics for a single device agent"""

    in_bytes: int = betterproto.uint32_field(1)
    in_messages: int = betterproto.uint32_field(2)
    out_bytes: int = betterproto.uint32_field(3)
    out_messages: int = betterproto.uint32_field(4)
    first_update_time: int = betterproto.uint64_field(5)
    last_update_time: int = betterproto.uint64_field(6)

    def __post_init__(self) -> None:
        super().__post_init__()



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: onos/mlb/mlb.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import Dict

import betterproto
import grpclib


@dataclass(eq=False, repr=False)
class GetMlbParamRequest(betterproto.Message):
    pass

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetMlbParamResponse(betterproto.Message):
    interval: int = betterproto.int32_field(1)
    overload_threshold: int = betterproto.int32_field(2)
    target_threshold: int = betterproto.int32_field(3)
    delta_ocn: int = betterproto.int32_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class SetMlbParamRequest(betterproto.Message):
    interval: int = betterproto.int32_field(1)
    overload_threshold: int = betterproto.int32_field(2)
    target_threshold: int = betterproto.int32_field(3)
    delta_ocn: int = betterproto.int32_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class SetMlbParamResponse(betterproto.Message):
    success: bool = betterproto.bool_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetOcnRequest(betterproto.Message):
    pass

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetOcnResponse(betterproto.Message):
    ocn_map: Dict[str, "OcnRecord"] = betterproto.map_field(
        1, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class OcnRecord(betterproto.Message):
    ocn_record: Dict[str, int] = betterproto.map_field(
        1, betterproto.TYPE_STRING, betterproto.TYPE_INT32
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class OcnIDs(betterproto.Message):
    pass

    def __post_init__(self) -> None:
        super().__post_init__()


class MlbStub(betterproto.ServiceStub):
    async def get_mlb_params(self) -> "GetMlbParamResponse":
        """GetMlbParams gets MLB parameters"""

        request = GetMlbParamRequest()

        return await self._unary_unary(
            "/onos.mlb.Mlb/GetMlbParams", request, GetMlbParamResponse
        )

    async def set_mlb_params(
        self,
        *,
        interval: int = 0,
        overload_threshold: int = 0,
        target_threshold: int = 0,
        delta_ocn: int = 0,
    ) -> "SetMlbParamResponse":
        """SetMlbParams sets MLB parameters"""

        request = SetMlbParamRequest()
        request.interval = interval
        request.overload_threshold = overload_threshold
        request.target_threshold = target_threshold
        request.delta_ocn = delta_ocn

        return await self._unary_unary(
            "/onos.mlb.Mlb/SetMlbParams", request, SetMlbParamResponse
        )

    async def get_ocn(self) -> "GetOcnResponse":
        """GetOcn gets Ocn map"""

        request = GetOcnRequest()

        return await self._unary_unary("/onos.mlb.Mlb/GetOcn", request, GetOcnResponse)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: onos/config/v2/value.proto, onos/config/v2/object.proto, onos/config/v2/failure.proto, onos/config/v2/transaction.proto, onos/config/v2/configuration.proto, onos/config/v2/proposal.proto
# plugin: python-betterproto
from dataclasses import dataclass
from datetime import datetime
from typing import Dict, List

import betterproto


class ValueType(betterproto.Enum):
    """ValueType is the type for a value"""

    EMPTY = 0
    STRING = 1
    INT = 2
    UINT = 3
    BOOL = 4
    DECIMAL = 5
    FLOAT = 6
    BYTES = 7
    LEAFLIST_STRING = 8
    LEAFLIST_INT = 9
    LEAFLIST_UINT = 10
    LEAFLIST_BOOL = 11
    LEAFLIST_DECIMAL = 12
    LEAFLIST_FLOAT = 13
    LEAFLIST_BYTES = 14
    DOUBLE = 15
    LEAFLIST_DOUBLE = 16


class FailureType(betterproto.Enum):
    UNKNOWN = 0
    CANCELED = 1
    NOT_FOUND = 2
    ALREADY_EXISTS = 3
    UNAUTHORIZED = 4
    FORBIDDEN = 5
    CONFLICT = 6
    INVALID = 7
    UNAVAILABLE = 8
    NOT_SUPPORTED = 9
    TIMEOUT = 10
    INTERNAL = 11


class TransactionStrategySynchronicity(betterproto.Enum):
    ASYNCHRONOUS = 0
    SYNCHRONOUS = 1


class TransactionStrategyIsolation(betterproto.Enum):
    DEFAULT = 0
    SERIALIZABLE = 1


class TransactionStatusState(betterproto.Enum):
    PENDING = 0
    VALIDATED = 1
    COMMITTED = 2
    APPLIED = 3
    FAILED = 4


class TransactionInitializePhaseState(betterproto.Enum):
    INITIALIZING = 0
    INITIALIZED = 1
    FAILED = 2


class TransactionValidatePhaseState(betterproto.Enum):
    VALIDATING = 0
    VALIDATED = 1
    FAILED = 2


class TransactionCommitPhaseState(betterproto.Enum):
    COMMITTING = 0
    COMMITTED = 1


class TransactionApplyPhaseState(betterproto.Enum):
    APPLYING = 0
    APPLIED = 1
    FAILED = 2


class TransactionAbortPhaseState(betterproto.Enum):
    ABORTING = 0
    ABORTED = 1


class TransactionEventEventType(betterproto.Enum):
    UNKNOWN = 0
    CREATED = 1
    UPDATED = 2
    DELETED = 3
    REPLAYED = 4


class ConfigurationStatusState(betterproto.Enum):
    UNKNOWN = 0
    SYNCHRONIZING = 1
    SYNCHRONIZED = 2
    PERSISTED = 3


class ConfigurationEventEventType(betterproto.Enum):
    UNKNOWN = 0
    CREATED = 1
    UPDATED = 2
    DELETED = 3
    REPLAYED = 4


class ProposalInitializePhaseState(betterproto.Enum):
    INITIALIZING = 0
    INITIALIZED = 1


class ProposalValidatePhaseState(betterproto.Enum):
    VALIDATING = 0
    VALIDATED = 1
    FAILED = 2


class ProposalCommitPhaseState(betterproto.Enum):
    COMMITTING = 0
    COMMITTED = 1


class ProposalApplyPhaseState(betterproto.Enum):
    APPLYING = 0
    APPLIED = 1
    FAILED = 2


class ProposalAbortPhaseState(betterproto.Enum):
    ABORTING = 0
    ABORTED = 1


class ProposalEventEventType(betterproto.Enum):
    UNKNOWN = 0
    CREATED = 1
    UPDATED = 2
    DELETED = 3
    REPLAYED = 4


@dataclass(eq=False, repr=False)
class TypedValue(betterproto.Message):
    """TypedValue is a value represented as a byte array"""

    # 'bytes' is the bytes array
    bytes: bytes = betterproto.bytes_field(1)
    # 'type' is the value type
    type: "ValueType" = betterproto.enum_field(2)
    # 'type_opts' is a set of type options
    type_opts: List[int] = betterproto.int32_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class PathValues(betterproto.Message):
    """PathValues is a set of path/value pairs"""

    # 'values' is a set of change values to apply
    values: Dict[str, "PathValue"] = betterproto.map_field(
        4, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class PathValue(betterproto.Message):
    """PathValue is the state of a path/value in the configuration tree"""

    # 'path' is the path to change
    path: str = betterproto.string_field(1)
    # 'value' is the change value
    value: "TypedValue" = betterproto.message_field(2)
    # 'deleted' indicates whether this is a delete
    deleted: bool = betterproto.bool_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ObjectMeta(betterproto.Message):
    """TypedValue is a value represented as a byte array"""

    # 'bytes' is the bytes array
    key: str = betterproto.string_field(1)
    # 'type' is the value type
    version: int = betterproto.uint64_field(2)
    # 'type_opts' is a set of type options
    revision: int = betterproto.uint64_field(3)
    created: datetime = betterproto.message_field(4)
    updated: datetime = betterproto.message_field(5)
    deleted: datetime = betterproto.message_field(6)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TargetTypeVersion(betterproto.Message):
    """PathValues is a set of path/value pairs"""

    # 'values' is a set of change values to apply
    target_type: str = betterproto.string_field(1)
    target_version: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Failure(betterproto.Message):
    """TypedValue is a value represented as a byte array"""

    # 'bytes' is the bytes array
    type: "FailureType" = betterproto.enum_field(1)
    # 'type' is the value type
    description: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TransactionInfo(betterproto.Message):
    """TypedValue is a value represented as a byte array"""

    # 'bytes' is the bytes array
    id: str = betterproto.string_field(1)
    # 'type' is the value type
    index: int = betterproto.uint64_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Transaction(betterproto.Message):
    """PathValues is a set of path/value pairs"""

    # 'values' is a set of change values to apply
    meta: "ObjectMeta" = betterproto.message_field(1)
    id: str = betterproto.string_field(2)
    index: int = betterproto.uint64_field(3)
    username: str = betterproto.string_field(4)
    strategy: "TransactionStrategy" = betterproto.message_field(5)
    change: "ChangeTransaction" = betterproto.message_field(6, group="details")
    rollback: "RollbackTransaction" = betterproto.message_field(7, group="details")
    status: "TransactionStatus" = betterproto.message_field(8)
    version_overrides: "TargetVersionOverrides" = betterproto.message_field(9)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TransactionStrategy(betterproto.Message):
    """PathValue is the state of a path/value in the configuration tree"""

    # 'path' is the path to change
    synchronicity: "TransactionStrategySynchronicity" = betterproto.enum_field(1)
    # 'value' is the change value
    isolation: "TransactionStrategyIsolation" = betterproto.enum_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ChangeTransaction(betterproto.Message):
    values: Dict[str, "PathValues"] = betterproto.map_field(
        1, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RollbackTransaction(betterproto.Message):
    rollback_index: int = betterproto.uint64_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TransactionStatus(betterproto.Message):
    phases: "TransactionPhases" = betterproto.message_field(1)
    proposals: List[str] = betterproto.string_field(2)
    state: "TransactionStatusState" = betterproto.enum_field(3)
    failure: "Failure" = betterproto.message_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TransactionPhases(betterproto.Message):
    initialize: "TransactionInitializePhase" = betterproto.message_field(1)
    validate: "TransactionValidatePhase" = betterproto.message_field(2)
    commit: "TransactionCommitPhase" = betterproto.message_field(3)
    apply: "TransactionApplyPhase" = betterproto.message_field(4)
    abort: "TransactionAbortPhase" = betterproto.message_field(5)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TransactionPhaseStatus(betterproto.Message):
    start: datetime = betterproto.message_field(1)
    end: datetime = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TransactionInitializePhase(betterproto.Message):
    status: "TransactionPhaseStatus" = betterproto.message_field(1)
    state: "TransactionInitializePhaseState" = betterproto.enum_field(2)
    failure: "Failure" = betterproto.message_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TransactionValidatePhase(betterproto.Message):
    status: "TransactionPhaseStatus" = betterproto.message_field(1)
    state: "TransactionValidatePhaseState" = betterproto.enum_field(2)
    failure: "Failure" = betterproto.message_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TransactionCommitPhase(betterproto.Message):
    status: "TransactionPhaseStatus" = betterproto.message_field(1)
    state: "TransactionCommitPhaseState" = betterproto.enum_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TransactionApplyPhase(betterproto.Message):
    status: "TransactionPhaseStatus" = betterproto.message_field(1)
    state: "TransactionApplyPhaseState" = betterproto.enum_field(2)
    failure: "Failure" = betterproto.message_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TransactionAbortPhase(betterproto.Message):
    status: "TransactionPhaseStatus" = betterproto.message_field(1)
    state: "TransactionAbortPhaseState" = betterproto.enum_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TransactionEvent(betterproto.Message):
    type: "TransactionEventEventType" = betterproto.enum_field(1)
    transaction: "Transaction" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class TargetVersionOverrides(betterproto.Message):
    overrides: Dict[str, "TargetTypeVersion"] = betterproto.map_field(
        1, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Configuration(betterproto.Message):
    """TypedValue is a value represented as a byte array"""

    # 'bytes' is the bytes array
    meta: "ObjectMeta" = betterproto.message_field(1)
    # 'type' is the value type
    id: str = betterproto.string_field(2)
    # 'type_opts' is a set of type options
    target_id: str = betterproto.string_field(3)
    values: Dict[str, "PathValue"] = betterproto.map_field(
        4, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )
    index: int = betterproto.uint64_field(5)
    status: "ConfigurationStatus" = betterproto.message_field(6)
    target_info: "TargetTypeVersion" = betterproto.message_field(7)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ConfigurationStatus(betterproto.Message):
    """PathValues is a set of path/value pairs"""

    # 'values' is a set of change values to apply
    state: "ConfigurationStatusState" = betterproto.enum_field(1)
    mastership: "MastershipInfo" = betterproto.message_field(2)
    proposed: "ProposedConfigurationStatus" = betterproto.message_field(3)
    committed: "CommittedConfigurationStatus" = betterproto.message_field(4)
    applied: "AppliedConfigurationStatus" = betterproto.message_field(5)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ProposedConfigurationStatus(betterproto.Message):
    """PathValue is the state of a path/value in the configuration tree"""

    # 'path' is the path to change
    index: int = betterproto.uint64_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class CommittedConfigurationStatus(betterproto.Message):
    index: int = betterproto.uint64_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class AppliedConfigurationStatus(betterproto.Message):
    index: int = betterproto.uint64_field(1)
    mastership: "MastershipInfo" = betterproto.message_field(2)
    values: Dict[str, "PathValue"] = betterproto.map_field(
        3, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class MastershipInfo(betterproto.Message):
    master: str = betterproto.string_field(1)
    term: int = betterproto.uint64_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ConfigurationEvent(betterproto.Message):
    type: "ConfigurationEventEventType" = betterproto.enum_field(1)
    configuration: "Configuration" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Proposal(betterproto.Message):
    """TypedValue is a value represented as a byte array"""

    # 'bytes' is the bytes array
    meta: "ObjectMeta" = betterproto.message_field(1)
    # 'type' is the value type
    id: str = betterproto.string_field(2)
    # 'type_opts' is a set of type options
    target_id: str = betterproto.string_field(3)
    transaction_index: int = betterproto.uint64_field(4)
    change: "ChangeProposal" = betterproto.message_field(5, group="details")
    rollback: "RollbackProposal" = betterproto.message_field(6, group="details")
    status: "ProposalStatus" = betterproto.message_field(7)
    target_info: "TargetTypeVersion" = betterproto.message_field(8)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ChangeProposal(betterproto.Message):
    """PathValues is a set of path/value pairs"""

    # 'values' is a set of change values to apply
    values: Dict[str, "PathValue"] = betterproto.map_field(
        1, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RollbackProposal(betterproto.Message):
    """PathValue is the state of a path/value in the configuration tree"""

    # 'path' is the path to change
    rollback_index: int = betterproto.uint64_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ProposalStatus(betterproto.Message):
    phases: "ProposalPhases" = betterproto.message_field(1)
    prev_index: int = betterproto.uint64_field(2)
    next_index: int = betterproto.uint64_field(3)
    rollback_index: int = betterproto.uint64_field(4)
    rollback_values: Dict[str, "PathValue"] = betterproto.map_field(
        5, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ProposalPhases(betterproto.Message):
    initialize: "ProposalInitializePhase" = betterproto.message_field(1)
    validate: "ProposalValidatePhase" = betterproto.message_field(2)
    commit: "ProposalCommitPhase" = betterproto.message_field(3)
    apply: "ProposalApplyPhase" = betterproto.message_field(4)
    abort: "ProposalAbortPhase" = betterproto.message_field(5)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ProposalPhaseStatus(betterproto.Message):
    start: datetime = betterproto.message_field(1)
    end: datetime = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ProposalInitializePhase(betterproto.Message):
    status: "ProposalPhaseStatus" = betterproto.message_field(1)
    state: "ProposalInitializePhaseState" = betterproto.enum_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ProposalValidatePhase(betterproto.Message):
    status: "ProposalPhaseStatus" = betterproto.message_field(1)
    state: "ProposalValidatePhaseState" = betterproto.enum_field(2)
    failure: "Failure" = betterproto.message_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ProposalCommitPhase(betterproto.Message):
    status: "ProposalPhaseStatus" = betterproto.message_field(1)
    state: "ProposalCommitPhaseState" = betterproto.enum_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ProposalApplyPhase(betterproto.Message):
    status: "ProposalPhaseStatus" = betterproto.message_field(1)
    state: "ProposalApplyPhaseState" = betterproto.enum_field(2)
    term: int = betterproto.uint64_field(3)
    failure: "Failure" = betterproto.message_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ProposalAbortPhase(betterproto.Message):
    status: "ProposalPhaseStatus" = betterproto.message_field(1)
    state: "ProposalAbortPhaseState" = betterproto.enum_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ProposalEvent(betterproto.Message):
    type: "ProposalEventEventType" = betterproto.enum_field(1)
    proposal: "Proposal" = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: onos/config/admin/admin.proto
# plugin: python-betterproto
import warnings
from dataclasses import dataclass
from typing import AsyncIterator, List, Optional

import betterproto
import grpclib


@dataclass(eq=False, repr=False)
class ReadOnlySubPath(betterproto.Message):
    """
    ReadOnlySubPath is an extension to the ReadOnlyPath to define the datatype
    of the subpath
    """

    # sub_path is the relative path of a child object e.g. /list2b/index
    sub_path: str = betterproto.string_field(1)
    # value_type is the datatype of the read only path
    value_type: "_v2__.ValueType" = betterproto.enum_field(2)
    type_opts: List[int] = betterproto.uint64_field(3)
    description: str = betterproto.string_field(4)
    units: str = betterproto.string_field(5)
    is_a_key: bool = betterproto.bool_field(6)
    attr_name: str = betterproto.string_field(7)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ReadOnlyPath(betterproto.Message):
    """
    ReadOnlyPath extracted from the model plugin as the definition of a tree of
    read only items. In YANG models items are defined as ReadOnly with the
    `config false` keyword. This can be applied to single items (leafs) or
    collections (containers or lists). When this `config false` is applied to
    an object every item beneath it will also become readonly - here these are
    shown as subpaths. The complete read only path then will be a concatenation
    of both e.g. /cont1a/cont1b-state/list2b/index and the type is defined in
    the SubPath as UInt8.
    """

    # path of the topmost `config false` object e.g. /cont1a/cont1b-state
    path: str = betterproto.string_field(1)
    # ReadOnlySubPath is a set of children of the path including an entry for the
    # type of the topmost object with subpath `/` An example is /list2b/index
    sub_path: List["ReadOnlySubPath"] = betterproto.message_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ReadWritePath(betterproto.Message):
    """
    ReadWritePath is extracted from the model plugin as the definition of a
    writeable attributes. In YANG models items are writable by default unless
    they are specified as `config false` or have an item with `config false` as
    a parent. Each configurable item has metadata with meanings taken from the
    YANG specification RFC 6020.
    """

    # path is the full path to the attribute (leaf or leaf-list)
    path: str = betterproto.string_field(1)
    # value_type is the data type of the attribute
    value_type: "_v2__.ValueType" = betterproto.enum_field(2)
    # units is the unit of measurement e.g. dB, mV
    units: str = betterproto.string_field(3)
    # description is an explaination of the meaning of the attribute
    description: str = betterproto.string_field(4)
    # mandatory shows whether the attribute is optional (false) or required
    # (true)
    mandatory: bool = betterproto.bool_field(5)
    # default is a default value used with optional attributes. Replaced by
    # 'defaults' below
    default: str = betterproto.string_field(6)
    # range is definition of the range of values a value is allowed
    range: List[str] = betterproto.string_field(7)
    # length is a defintion of the length restrictions for the attribute
    length: List[str] = betterproto.string_field(8)
    type_opts: List[int] = betterproto.uint64_field(9)
    is_a_key: bool = betterproto.bool_field(10)
    attr_name: str = betterproto.string_field(11)
    # defaults is a default value(s) used with optional attributes. For leaf-list
    # can have repeated values replaces the 'default' attribute above
    defaults: List[str] = betterproto.string_field(12)

    def __post_init__(self) -> None:
        super().__post_init__()
        if self.default:
            warnings.warn("ReadWritePath.default is deprecated", DeprecationWarning)


@dataclass(eq=False, repr=False)
class Namespace(betterproto.Message):
    """
    Namespace is a mapping between a module name and its shorthand prefix
    """

    module: str = betterproto.string_field(1)
    prefix: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ModelInfo(betterproto.Message):
    """ModelInfo is general information about a model plugin."""

    # name is the name given to the model plugin - no spaces and title case.
    name: str = betterproto.string_field(1)
    # version is the semantic version of the Plugin e.g. 1.0.0.
    version: str = betterproto.string_field(2)
    # model_data is a set of metadata about the YANG files that went in to
    # generating the model plugin. It includes name, version and organization for
    # each YANG file, similar to how they are represented in gNMI Capabilities.
    model_data: List["___gnmi__.ModelData"] = betterproto.message_field(3)
    # module is no longer used
    module: str = betterproto.string_field(4)
    # getStateMode is flag that defines how the "get state" operation works.  0)
    # means that no retrieval of state is attempted  1) means that the
    # synchronizer will make 2 requests to the device - one for      Get with
    # State and another for Get with Operational.  2) means that the synchronizer
    # will do a Get request comprising of each      one of the ReadOnlyPaths and
    # their sub paths. If there is a `list`      in any one of these paths it
    # will be sent down as is, expecting the      devices implementation of gNMI
    # will be able to expand wildcards.  3) means that the synchronizer will do a
    # Get request comprising of each      one of the ReadOnlyPaths and their sub
    # paths. If there is a `list`      in any one of these paths, a separate call
    # will be made first to find      all the instances in the list and a Get
    # including these expanded wildcards      will be sent down to the device.
    get_state_mode: int = betterproto.uint32_field(5)
    # read_only_path is all of the read only paths for the model plugin.
    read_only_path: List["ReadOnlyPath"] = betterproto.message_field(7)
    # read_write_path is all of the read write paths for the model plugin.
    read_write_path: List["ReadWritePath"] = betterproto.message_field(8)
    supported_encodings: List["___gnmi__.Encoding"] = betterproto.enum_field(9)
    # namespace_mappings is a set of all prefix to module name mapping in the
    # model
    namespace_mappings: List["Namespace"] = betterproto.message_field(10)
    # southboundUsePrefix indicates that the southbound should add prefixes in
    # gNMI paths
    southbound_use_prefix: bool = betterproto.bool_field(11)

    def __post_init__(self) -> None:
        super().__post_init__()
        if self.module:
            warnings.warn("ModelInfo.module is deprecated", DeprecationWarning)


@dataclass(eq=False, repr=False)
class ModelPlugin(betterproto.Message):
    id: str = betterproto.string_field(1)
    endpoint: str = betterproto.string_field(2)
    info: "ModelInfo" = betterproto.message_field(3)
    status: str = betterproto.string_field(10)
    error: str = betterproto.string_field(11)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ListModelsRequest(betterproto.Message):
    """
    ListModelsRequest carries data for querying registered model plugins.
    """

    # verbose option causes all of the ReadWrite and ReadOnly paths to be
    # included.
    verbose: bool = betterproto.bool_field(1)
    # An optional filter on the name of the model plugins to list.
    model_name: str = betterproto.string_field(2)
    # An optional filter on the version of the model plugins to list
    model_version: str = betterproto.string_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RollbackRequest(betterproto.Message):
    """
    RollbackRequest carries the index of the configuration change transaction
    to rollback.
    """

    # index of the transaction that should be rolled back
    index: int = betterproto.uint64_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RollbackResponse(betterproto.Message):
    """RollbackResponse carries the response of the rollback operation"""

    # ID of the rollback transaction
    id: str = betterproto.string_field(1)
    # index of the rollback transaction
    index: int = betterproto.uint64_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class LeafSelectionQueryRequest(betterproto.Message):
    """
    LeafSelectionQueryRequest carries request for the selection of leaf values
    """

    # target is the name of the target (device) to perform the query on
    target: str = betterproto.string_field(1)
    # type of model plugin to perform the query on
    type: str = betterproto.string_field(2)
    # version of model plugin to perform the query on
    version: str = betterproto.string_field(3)
    # selectionPath is a configuration path to a leaf in the format:
    # /a/b[key1=index][key2=index2]/c/d where d is a leaf node
    selection_path: str = betterproto.string_field(4)
    # changeContext is the set of changes (e.g. from the GUI form) that have to
    # be superimposed on the current configuration before the leaf selection can
    # be made All the changes in this request should match the target given above
    # optional
    change_context: "___gnmi__.SetRequest" = betterproto.message_field(5)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class LeafSelectionQueryResponse(betterproto.Message):
    """
    LeafSelectionQueryResponse carries response for the model information query
    """

    # selection is an array of string values
    selection: List[str] = betterproto.string_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ModelInfoRequest(betterproto.Message):
    """ModelInfoRequest carries request for the model information"""

    pass

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ModelInfoResponse(betterproto.Message):
    """ModelInfoResponse carries response for the model information query"""

    model_info: "ModelInfo" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ValidateConfigRequest(betterproto.Message):
    """
    ValidateConfigRequest carries configuration data to be validated as a JSON
    blob
    """

    json: bytes = betterproto.bytes_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ValidateConfigResponse(betterproto.Message):
    """ValidateConfigResponse carries the result of the validation"""

    valid: bool = betterproto.bool_field(1)
    message: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class PathValuesRequest(betterproto.Message):
    """PathValuesRequest carries configuration change as a JSON blob"""

    path_prefix: str = betterproto.string_field(1)
    json: bytes = betterproto.bytes_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class PathValuesResponse(betterproto.Message):
    """PathValuesResponse carries a list of typed path values"""

    path_values: List["_v2__.PathValue"] = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ValueSelectionRequest(betterproto.Message):
    """
    ValueSelectionRequest carries the necessary parts to form a selection
    context
    """

    # selectionPath is a configuration path to a leaf in the format:
    # /a/b[key1=index][key2=index2]/c/d where d is a leaf node
    selection_path: str = betterproto.string_field(1)
    # configJson is a JSON tree view of the complete Configuration for a Target
    config_json: bytes = betterproto.bytes_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ValueSelectionResponse(betterproto.Message):
    """
    ValueSelectionResponse returns the result of applying the selection rules
    to the selection context
    """

    # selection is an array of string values
    selection: List[str] = betterproto.string_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetTransactionRequest(betterproto.Message):
    # ID of transaction to get
    id: str = betterproto.string_field(1)
    # index of transaction to get; leave 0 for lookup by ID; if specified takes
    # precedence
    index: int = betterproto.uint64_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetTransactionResponse(betterproto.Message):
    transaction: "_v2__.Transaction" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ListTransactionsRequest(betterproto.Message):
    pass

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ListTransactionsResponse(betterproto.Message):
    transaction: "_v2__.Transaction" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class WatchTransactionsRequest(betterproto.Message):
    id: str = betterproto.string_field(1)
    noreplay: bool = betterproto.bool_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class WatchTransactionsResponse(betterproto.Message):
    event: "_v2__.TransactionEvent" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetConfigurationRequest(betterproto.Message):
    configuration_id: str = betterproto.string_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetConfigurationResponse(betterproto.Message):
    configuration: "_v2__.Configuration" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ListConfigurationsRequest(betterproto.Message):
    pass

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class ListConfigurationsResponse(betterproto.Message):
    configuration: "_v2__.Configuration" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class WatchConfigurationsRequest(betterproto.Message):
    configuration_id: str = betterproto.string_field(1)
    noreplay: bool = betterproto.bool_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class WatchConfigurationsResponse(betterproto.Message):
    event: "_v2__.ConfigurationEvent" = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


class ConfigAdminServiceStub(betterproto.ServiceStub):
    """
    ConfigAdminService provides means for enhanced interactions with the
    configuration subsystem.
    """

    async def list_registered_models(
        self, *, verbose: bool = False, model_name: str = "", model_version: str = ""
    ) -> AsyncIterator["ModelPlugin"]:
        """ListRegisteredModels returns a stream of registered models."""

        request = ListModelsRequest()
        request.verbose = verbose
        request.model_name = model_name
        request.model_version = model_version

        async for response in self._unary_stream(
            "/onos.config.admin.ConfigAdminService/ListRegisteredModels",
            request,
            ModelPlugin,
        ):
            yield response

    async def rollback_transaction(self, *, index: int = 0) -> "RollbackResponse":
        """
        RollbackTransaction rolls back the specified configuration change
        transaction.
        """

        request = RollbackRequest()
        request.index = index

        return await self._unary_unary(
            "/onos.config.admin.ConfigAdminService/RollbackTransaction",
            request,
            RollbackResponse,
        )

    async def leaf_selection_query(
        self,
        *,
        target: str = "",
        type: str = "",
        version: str = "",
        selection_path: str = "",
        change_context: "___gnmi__.SetRequest" = None,
    ) -> "LeafSelectionQueryResponse":
        """
        LeafSelectionQuery selects values allowable for leaf. It supports the
        ROC GUI by supplying a list of valid leaf values based off an XPath
        query defined in a 'leaf-selection' YANG extension Calls on
        GetValueSelection RPC on Model Plugin
        """

        request = LeafSelectionQueryRequest()
        request.target = target
        request.type = type
        request.version = version
        request.selection_path = selection_path
        if change_context is not None:
            request.change_context = change_context

        return await self._unary_unary(
            "/onos.config.admin.ConfigAdminService/LeafSelectionQuery",
            request,
            LeafSelectionQueryResponse,
        )


class ModelPluginServiceStub(betterproto.ServiceStub):
    """ModelPluginService is to be implemented by model plugin sidecar"""

    async def get_model_info(self) -> "ModelInfoResponse":
        """GetModelInfo provides information about the model"""

        request = ModelInfoRequest()

        return await self._unary_unary(
            "/onos.config.admin.ModelPluginService/GetModelInfo",
            request,
            ModelInfoResponse,
        )

    async def validate_config(self, *, json: bytes = b"") -> "ValidateConfigResponse":
        """
        ValidateConfig validates the provided configuration data against the
        model
        """

        request = ValidateConfigRequest()
        request.json = json

        return await self._unary_unary(
            "/onos.config.admin.ModelPluginService/ValidateConfig",
            request,
            ValidateConfigResponse,
        )

    async def get_path_values(
        self, *, path_prefix: str = "", json: bytes = b""
    ) -> "PathValuesResponse":
        """
        GetPathValues produces list of typed path value entries from the
        specified configuration change JSON tree
        """

        request = PathValuesRequest()
        request.path_prefix = path_prefix
        request.json = json

        return await self._unary_unary(
            "/onos.config.admin.ModelPluginService/GetPathValues",
            request,
            PathValuesResponse,
        )

    async def get_value_selection(
        self, *, selection_path: str = "", config_json: bytes = b""
    ) -> "ValueSelectionResponse":
        """
        GetValueSelection gets a list of valid options for a leaf by applying
        selection rules in YANG. The selection rules should be defined as an
        XPath expression, as an argument to a `leaf-selection` extension in the
        YANG model (Used to support the ROC GUI)
        """

        request = ValueSelectionRequest()
        request.selection_path = selection_path
        request.config_json = config_json

        return await self._unary_unary(
            "/onos.config.admin.ModelPluginService/GetValueSelection",
            request,
            ValueSelectionResponse,
        )


class TransactionServiceStub(betterproto.ServiceStub):
    """
    TransactionService provides means to inspect the contents of the internal
    transactions store.
    """

    async def get_transaction(
        self, *, id: str = "", index: int = 0
    ) -> "GetTransactionResponse":
        """Get transaction by its ID or index"""

        request = GetTransactionRequest()
        request.id = id
        request.index = index

        return await self._unary_unary(
            "/onos.config.admin.TransactionService/GetTransaction",
            request,
            GetTransactionResponse,
        )

    async def list_transactions(self) -> AsyncIterator["ListTransactionsResponse"]:
        """List returns all configuration transactions"""

        request = ListTransactionsRequest()

        async for response in self._unary_stream(
            "/onos.config.admin.TransactionService/ListTransactions",
            request,
            ListTransactionsResponse,
        ):
            yield response

    async def watch_transactions(
        self, *, id: str = "", noreplay: bool = False
    ) -> AsyncIterator["WatchTransactionsResponse"]:
        """
        Watch returns a stream of configuration transaction change
        notifications
        """

        request = WatchTransactionsRequest()
        request.id = id
        request.noreplay = noreplay

        async for response in self._unary_stream(
            "/onos.config.admin.TransactionService/WatchTransactions",
            request,
            WatchTransactionsResponse,
        ):
            yield response


class ConfigurationServiceStub(betterproto.ServiceStub):
    """
    ConfigurationService provides means to inspect the contents of the internal
    configurations store.
    """

    async def get_configuration(
        self, *, configuration_id: str = ""
    ) -> "GetConfigurationResponse":
        """Get configuration by its target ID"""

        request = GetConfigurationRequest()
        request.configuration_id = configuration_id

        return await self._unary_unary(
            "/onos.config.admin.ConfigurationService/GetConfiguration",
            request,
            GetConfigurationResponse,
        )

    async def list_configurations(self) -> AsyncIterator["ListConfigurationsResponse"]:
        """List returns all target configurations"""

        request = ListConfigurationsRequest()

        async for response in self._unary_stream(
            "/onos.config.admin.ConfigurationService/ListConfigurations",
            request,
            ListConfigurationsResponse,
        ):
            yield response

    async def watch_configurations(
        self, *, configuration_id: str = "", noreplay: bool = False
    ) -> AsyncIterator["WatchConfigurationsResponse"]:
        """Watch returns a stream of configuration change notifications"""

        request = WatchConfigurationsRequest()
        request.configuration_id = configuration_id
        request.noreplay = noreplay

        async for response in self._unary_stream(
            "/onos.config.admin.ConfigurationService/WatchConfigurations",
            request,
            WatchConfigurationsResponse,
        ):
            yield response


from .. import v2 as _v2__
from .... import gnmi as ___gnmi__



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: onos/discovery/discovery.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import List

import betterproto
import grpclib


@dataclass(eq=False, repr=False)
class AddPodRequest(betterproto.Message):
    id: str = betterproto.string_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class AddPodResponse(betterproto.Message):
    pass

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class AddRackRequest(betterproto.Message):
    id: str = betterproto.string_field(1)
    pod_id: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class AddRackResponse(betterproto.Message):
    pass

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class AddSwitchRequest(betterproto.Message):
    id: str = betterproto.string_field(1)
    pod_id: str = betterproto.string_field(2)
    rack_id: str = betterproto.string_field(3)
    p4_endpoint: str = betterproto.string_field(4)
    gnmi_endpoint: str = betterproto.string_field(5)
    pipeline_config_id: str = betterproto.string_field(6)
    chassis_config_id: str = betterproto.string_field(7)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class AddSwitchResponse(betterproto.Message):
    pass

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class AddServerIpuRequest(betterproto.Message):
    id: str = betterproto.string_field(1)
    pod_id: str = betterproto.string_field(2)
    rack_id: str = betterproto.string_field(3)
    p4_endpoint: str = betterproto.string_field(4)
    gnmi_endpoint: str = betterproto.string_field(5)
    pipeline_config_id: str = betterproto.string_field(6)
    chassis_config_id: str = betterproto.string_field(7)
    links: List["InjectedLink"] = betterproto.message_field(8)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class InjectedLink(betterproto.Message):
    port: int = betterproto.uint64_field(1)
    remote_port: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class AddServerIpuResponse(betterproto.Message):
    pass

    def __post_init__(self) -> None:
        super().__post_init__()


class DiscoveryServiceStub(betterproto.ServiceStub):
    """
    DiscoveryService allows injection of topology objects to act as seeds for
    the topology discovery.
    """

    async def add_pod(self, *, id: str = "") -> "AddPodResponse":
        """AddPod adds a new POD entity with the requisite aspects"""

        request = AddPodRequest()
        request.id = id

        return await self._unary_unary(
            "/onos.discovery.DiscoveryService/AddPod", request, AddPodResponse
        )

    async def add_rack(self, *, id: str = "", pod_id: str = "") -> "AddRackResponse":
        """
        AddRack adds a new rack entity with the requisite aspects as part of a
        POD
        """

        request = AddRackRequest()
        request.id = id
        request.pod_id = pod_id

        return await self._unary_unary(
            "/onos.discovery.DiscoveryService/AddRack", request, AddRackResponse
        )

    async def add_switch(
        self,
        *,
        id: str = "",
        pod_id: str = "",
        rack_id: str = "",
        p4_endpoint: str = "",
        gnmi_endpoint: str = "",
        pipeline_config_id: str = "",
        chassis_config_id: str = "",
    ) -> "AddSwitchResponse":
        """
        AddSwitch adds a new switch entity with the requisite aspects into a
        rack
        """

        request = AddSwitchRequest()
        request.id = id
        request.pod_id = pod_id
        request.rack_id = rack_id
        request.p4_endpoint = p4_endpoint
        request.gnmi_endpoint = gnmi_endpoint
        request.pipeline_config_id = pipeline_config_id
        request.chassis_config_id = chassis_config_id

        return await self._unary_unary(
            "/onos.discovery.DiscoveryService/AddSwitch", request, AddSwitchResponse
        )

    async def add_server_ipu(self) -> "AddServerIpuResponse":
        """
        AddServerIPU adds a new server entity and an associated IPU entity,
        both with the requisite aspects into a rack
        """

        request = AddServerIpuRequest()

        return await self._unary_unary(
            "/onos.discovery.DiscoveryService/AddServerIPU",
            request,
            AddServerIpuResponse,
        )



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: onos/o1t/o1t.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import AsyncIterator, Dict

import betterproto
import grpclib


@dataclass(eq=False, repr=False)
class GetRequest(betterproto.Message):
    pass

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetResponse(betterproto.Message):
    sessions: Dict[str, "Session"] = betterproto.map_field(
        1, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Session(betterproto.Message):
    session_id: str = betterproto.string_field(1)
    alive: bool = betterproto.bool_field(2)
    operations: Dict[str, "Operation"] = betterproto.map_field(
        3, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Operation(betterproto.Message):
    name: str = betterproto.string_field(1)
    timestamp: int = betterproto.uint64_field(2)
    namespace: str = betterproto.string_field(3)
    status: bool = betterproto.bool_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


class NetconfSessionsStub(betterproto.ServiceStub):
    async def list(self) -> "GetResponse":

        request = GetRequest()

        return await self._unary_unary(
            "/onos.o1t.NetconfSessions/List", request, GetResponse
        )

    async def watch(self) -> AsyncIterator["GetResponse"]:

        request = GetRequest()

        async for response in self._unary_stream(
            "/onos.o1t.NetconfSessions/Watch",
            request,
            GetResponse,
        ):
            yield response



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: onos/mho/mho.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import List

import betterproto
import grpclib


@dataclass(eq=False, repr=False)
class GetRequest(betterproto.Message):
    pass

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class UeList(betterproto.Message):
    ues: List["Ue"] = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class CellList(betterproto.Message):
    cells: List["Cell"] = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Ue(betterproto.Message):
    ue_id: str = betterproto.string_field(1)
    ho_state: str = betterproto.string_field(2)
    cgi: str = betterproto.string_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class Cell(betterproto.Message):
    cgi: str = betterproto.string_field(1)
    num_ues: int = betterproto.int64_field(2)
    cumulative_handovers_in: int = betterproto.int64_field(4)
    cumulative_handovers_out: int = betterproto.int64_field(5)

    def __post_init__(self) -> None:
        super().__post_init__()


class MhoStub(betterproto.ServiceStub):
    async def get_ues(self) -> "UeList":

        request = GetRequest()

        return await self._unary_unary("/onos.mho.mho/GetUes", request, UeList)

    async def get_cells(self) -> "CellList":

        request = GetRequest()

        return await self._unary_unary("/onos.mho.mho/GetCells", request, CellList)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: onos/perf/perf.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import AsyncIterable, AsyncIterator, Iterable, Optional, Union

import betterproto
import grpclib


@dataclass(eq=False, repr=False)
class Data(betterproto.Message):
    length: int = betterproto.uint32_field(1)
    data: bytes = betterproto.bytes_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class PingRequest(betterproto.Message):
    payload: "Data" = betterproto.message_field(1)
    timestamp: int = betterproto.uint64_field(2)
    repeat_count: int = betterproto.uint32_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class PingResponse(betterproto.Message):
    payload: "Data" = betterproto.message_field(1)
    timestamp: int = betterproto.uint64_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


class PerfServiceStub(betterproto.ServiceStub):
    """PerfService provides a simple API for benchmarking gRPC."""

    async def ping(
        self, *, payload: "Data" = None, timestamp: int = 0, repeat_count: int = 0
    ) -> "PingResponse":

        request = PingRequest()
        if payload is not None:
            request.payload = payload
        request.timestamp = timestamp
        request.repeat_count = repeat_count

        return await self._unary_unary(
            "/onos.perf.PerfService/Ping", request, PingResponse
        )

    async def ping_stream(
        self,
        request_iterator: Union[AsyncIterable["PingRequest"], Iterable["PingRequest"]],
    ) -> AsyncIterator["PingResponse"]:

        async for response in self._stream_stream(
            "/onos.perf.PerfService/PingStream",
            request_iterator,
            PingRequest,
            PingResponse,
        ):
            yield response



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: onos/a1t/admin/admin.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import AsyncIterator, List

import betterproto
import grpclib


@dataclass(eq=False, repr=False)
class GetXAppConnectionsRequest(betterproto.Message):
    xapp_id: str = betterproto.string_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetXAppConnectionResponse(betterproto.Message):
    xapp_id: str = betterproto.string_field(1)
    supported_a1_service: str = betterproto.string_field(2)
    supported_a1_service_type_id: str = betterproto.string_field(3)
    xapp_a1_endpoint: str = betterproto.string_field(4)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetPolicyTypeObjectRequest(betterproto.Message):
    policy_type_id: str = betterproto.string_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetPolicyTypeObjectResponse(betterproto.Message):
    policy_type_id: str = betterproto.string_field(1)
    policy_ids: List[str] = betterproto.string_field(2)
    policy_type_object: str = betterproto.string_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetPolicyObjectRequest(betterproto.Message):
    policy_type_id: str = betterproto.string_field(1)
    policy_object_id: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetPolicyObjectResponse(betterproto.Message):
    policy_type_id: str = betterproto.string_field(1)
    policy_object_id: str = betterproto.string_field(2)
    policy_object: str = betterproto.string_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetPolicyObjectStatusRequest(betterproto.Message):
    policy_type_id: str = betterproto.string_field(1)
    policy_object_id: str = betterproto.string_field(2)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetPolicyObjectStatusResponse(betterproto.Message):
    policy_type_id: str = betterproto.string_field(1)
    policy_object_id: str = betterproto.string_field(2)
    policy_object_status: str = betterproto.string_field(3)

    def __post_init__(self) -> None:
        super().__post_init__()


class A1TAdminServiceStub(betterproto.ServiceStub):
    async def get_x_app_connections(
        self, *, xapp_id: str = ""
    ) -> AsyncIterator["GetXAppConnectionResponse"]:
        """GetXAppConnections"""

        request = GetXAppConnectionsRequest()
        request.xapp_id = xapp_id

        async for response in self._unary_stream(
            "/onos.a1t.admin.A1TAdminService/GetXAppConnections",
            request,
            GetXAppConnectionResponse,
        ):
            yield response

    async def get_policy_type_object(
        self, *, policy_type_id: str = ""
    ) -> AsyncIterator["GetPolicyTypeObjectResponse"]:
        """GetPolicyTypeObject"""

        request = GetPolicyTypeObjectRequest()
        request.policy_type_id = policy_type_id

        async for response in self._unary_stream(
            "/onos.a1t.admin.A1TAdminService/GetPolicyTypeObject",
            request,
            GetPolicyTypeObjectResponse,
        ):
            yield response

    async def get_policy_object(
        self, *, policy_type_id: str = "", policy_object_id: str = ""
    ) -> AsyncIterator["GetPolicyObjectResponse"]:
        """GetPolicyObject"""

        request = GetPolicyObjectRequest()
        request.policy_type_id = policy_type_id
        request.policy_object_id = policy_object_id

        async for response in self._unary_stream(
            "/onos.a1t.admin.A1TAdminService/GetPolicyObject",
            request,
            GetPolicyObjectResponse,
        ):
            yield response

    async def get_policy_object_status(
        self, *, policy_type_id: str = "", policy_object_id: str = ""
    ) -> AsyncIterator["GetPolicyObjectStatusResponse"]:
        """GetPolicyObjectStatus"""

        request = GetPolicyObjectStatusRequest()
        request.policy_type_id = policy_type_id
        request.policy_object_id = policy_object_id

        async for response in self._unary_stream(
            "/onos.a1t.admin.A1TAdminService/GetPolicyObjectStatus",
            request,
            GetPolicyObjectStatusResponse,
        ):
            yield response



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: onos/kpimon/kpimon.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import AsyncIterator, Dict, List

import betterproto
import grpclib


@dataclass(eq=False, repr=False)
class GetRequest(betterproto.Message):
    pass

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class GetResponse(betterproto.Message):
    measurements: Dict[str, "MeasurementItems"] = betterproto.map_field(
        1, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class MeasurementItems(betterproto.Message):
    measurement_items: List["MeasurementItem"] = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class MeasurementItem(betterproto.Message):
    measurement_records: List["MeasurementRecord"] = betterproto.message_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class IntegerValue(betterproto.Message):
    value: int = betterproto.int64_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class RealValue(betterproto.Message):
    value: float = betterproto.double_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class NoValue(betterproto.Message):
    value: int = betterproto.int32_field(1)

    def __post_init__(self) -> None:
        super().__post_init__()


@dataclass(eq=False, repr=False)
class MeasurementRecord(betterproto.Message):
    timestamp: int = betterproto.uint64_field(2)
    measurement_name: str = betterproto.string_field(3)
    measurement_value: "betterproto_lib_google_protobuf.Any" = (
        betterproto.message_field(4)
    )

    def __post_init__(self) -> None:
        super().__post_init__()


class KpimonStub(betterproto.ServiceStub):
    async def list_measurements(self) -> "GetResponse":

        request = GetRequest()

        return await self._unary_unary(
            "/onos.kpimon.Kpimon/ListMeasurements", request, GetResponse
        )

    async def watch_measurements(self) -> AsyncIterator["GetResponse"]:

        request = GetRequest()

        async for response in self._unary_stream(
            "/onos.kpimon.Kpimon/WatchMeasurements",
            request,
            GetResponse,
        ):
            yield response


import betterproto.lib.google.protobuf as betterproto_lib_google_protobuf
